#
# spec file for package python-cssutils
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-cssutils
Version:        1.0.2
Release:        3.2
Summary:        A CSS Cascading Style Sheets library for Python
License:        LGPL-3.0-or-later
Group:          Development/Languages/Python
URL:            http://cthedot.de/cssutils/
Source:         https://files.pythonhosted.org/packages/source/c/cssutils/cssutils-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  python-rpm-macros
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
%ifpython2
Provides:       %{oldpython}-css-utils-doc = %{version}
Obsoletes:      %{oldpython}-css-utils-doc < %{version}
%endif
%python_subpackages

%description
A Python package to parse and build CSS Cascading Style Sheets. DOM only, not any rendering facilities!

%prep
%setup -q -n cssutils-%{version}
sed -i "1d" src/cssutils/{parse,codec,sac,serialize,scripts/csscapture,_codec2,errorhandler,scripts/cssparse,_codec3,scripts/csscombine,tokenize2,__init__}.py # Fix non-executable scripts
sed -i "s/\r//" src/cssutils/{sac,scripts/csscombine,tokenize2}.py COPYING COPYING.LESSER examples/{website,minify,imports,cssencodings,style,testutil,codec}.py # Fix EOL encodings

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/csscapture
%python_clone -a %{buildroot}%{_bindir}/csscombine
%python_clone -a %{buildroot}%{_bindir}/cssparse

%post
%{python_install_alternative csscapture csscombine cssparse}

%postun
%python_uninstall_alternative csscapture

%files %{python_files}
%license COPYING COPYING.LESSER
%doc README.txt examples
%python_alternative %{_bindir}/csscapture
%python_alternative %{_bindir}/csscombine
%python_alternative %{_bindir}/cssparse
%{python_sitelib}/cssutils-%{version}-py*.egg-info/
%{python_sitelib}/cssutils/
%{python_sitelib}/encutils/

%changelog
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Thu Aug 24 2017 jmatejek@suse.com
- singlespec auto-conversion
* Tue May  2 2017 thorsten.behrens@cib.de
- update to version 1.0.2:
  * Fixed issue #61: Nesting of `@media` rules
  * Fixed issue #51 and #56: Slow font-family regex
  * Fixed issue #68: failing tests on Python 3
  * Fixed issue #69: our DOM implementation now delegates unsupported
    methods
  * Fixed issue #72: importing now faster since regexes are no longer
    pre-cached on import time
* Tue May  2 2017 thorsten.behrens@cib.de
- update to version 1.0.1:
  * Fixed Python 3.5 compatibility
* Sat May  2 2015 benoit.monin@gmx.fr
- update to version 1.0:
  * EXPERIMENTAL: Variable references may have a fallback value now
    (as implemented in Firefox 29). It is available as
    CSSVariable.fallback and example are:
  * FEATURE: (issue #37) Implemented parsing of CSSCalc values.
    General syntax is checked but not if operators in calc are
    actually the right kind like DIMENSION * DIMENSION. Also Values
    using calc do not validate in cssutils but are actually valid.
  * FIXED issue #20 and #35 (Test fail CSSParser.parseUrl() error
    with Python 3.3)
  * FIXED issue #21: (almost all) deprecation warning in Py 3.3
    fixed.
  * FIXED issue #30 (Test failed)
  * FIXED issue #33 (well kinda): Added that cssutils is **not**
    threadsafe!
  * FIXED issue #34: More complext MediaQueries should be parsable
    now. A few slight changes in behavior are:
  - xml.dom.SyntaxErr raised instead of
    xml.dom.InvalidCharacterErr for an unknown media type
  - removed handheld media type special case (for old Opera).
* Thu Oct 24 2013 speilicke@suse.com
- Require python-setuptools instead of distribute (upstreams merged)
* Wed Apr 17 2013 toddrme2178@gmail.com
- Update to version 0.9.10:
  * No changelog provided
* Tue Apr 16 2013 p.drouand@gmail.com
- Remove BuildRequires: python-2to3, useless since included in main
  python devel package
- Add Requires: python3; fix build for OpenSUSE <= 12.2
* Fri Jan 11 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Mar 12 2012 saschpe@gmx.de
- Update to version 9.9.9:
  * No changelog provided
* Wed Sep  7 2011 saschpe@suse.de
- Obsolete/Provide python-cssutils-doc
* Fri Sep  2 2011 saschpe@suse.de
- Update to version 0.9.8a3:
  * No HTML docs anymore
- Spec file cleanup
* Thu Jan  6 2011 rwobben@hotmail.com
- Update to version 0.9.8a1
  * BUGFIX: fixes issue #41, #42, #45, #46
* Mon Nov  8 2010 rwobben@hotmail.com
- Update to 0.9.7b4
  * improves parsing of MS specific (and probably invalid!) values
* Mon Nov  8 2010 pth@suse.de
- Make package own the documentation subdir.
- Mark documentation as such.
* Tue Sep 14 2010 coolo@novell.com
- update to 0.9.7b3
- several changes (see CHANGELOG.txt), just random picks:
  * Massive speed improvement of handling of CSSVariables of a stylesheet
  * CSSFunction value parameters may contain HASH values like ``#fff`` now
  * Changed parameters of script/utility function ``csscombine``.
- sphinx conf no longer provided
* Tue May 18 2010 prusnak@suse.cz
- Update to 0.9.7a4
- cleanup spec file
- api changes:
  * CSSRule values changed: NAMESPACE_RULE, COMMENT, VARIABLES_RULE
  * CSSStyleSheet.setSerializer and CSSStyleSheet.setSerializerPref DEPRECATED
- compliance to http://dev.w3.org/csswg/cssom improved.
- new features:
  * Started CSS Variables <http://disruptive-innovations.com/zoo/cssvariables/>
  * added cssutils.css.CSSStyleSheet.variables
  * cssutils.ser.prefs.resolveVariables switchable
  * cssutils.ser.prefs.normalizedVarNames switchable
  * Added new options to cssutils.script.csscombine: cssText=None, href=None
  * Added CSSRuleList.rulesOfType(type)
* Mon May 17 2010 toms@suse.de
- Update to 0.9.7a3 as needed for FATE#309541
- Added build requirement for python-sphinx
- Added patch for copy.py (sphinx documentation)
- Rebuild HTML documentation with sphinx
- Better separate documentation package from main package
* Mon Apr 28 2008 pth@suse.de
- Initial package.
